@@ -4,13 +4,12 @@ use strict;
 use warnings;
 
 our $AUTHORITY = 'cpan:PERLANCAR'; # AUTHORITY
-our $DATE = '2024-04-12'; # DATE
+our $DATE = '2024-05-06'; # DATE
 our $DIST = 'Acme-CPANAuthorsBundle-CPAN-Streaks'; # DIST
-our $VERSION = '20240412.0'; # VERSION
+our $VERSION = '20240506.0'; # VERSION
 
 use Acme::CPANAuthors::Register (
     'PERLANCAR' => '',
-    'SKIM' => '',
 );
 
 
@@ -29,20 +28,19 @@ Acme::CPANAuthors::CPAN::Streaks::DailyDistributions::Current - Authors with ong
 
 =head1 VERSION
 
-This document describes version 20240412.0 of Acme::CPANAuthors::CPAN::Streaks::DailyDistributions::Current (from Perl distribution Acme-CPANAuthorsBundle-CPAN-Streaks), released on 2024-04-12.
+This document describes version 20240506.0 of Acme::CPANAuthors::CPAN::Streaks::DailyDistributions::Current (from Perl distribution Acme-CPANAuthorsBundle-CPAN-Streaks), released on 2024-05-06.
 
 =head1 SYNOPSIS
 
 =head1 DESCRIPTION
 
-Current standings (as of 2024-04-12, produced by L<cpan-streaks>):
+Current standings (as of 2024-05-06, produced by L<cpan-streaks>):
 
-  +-----------+-----+------------+-------------+
-  | author    | len | start_date | status      |
-  +-----------+-----+------------+-------------+
-  | PERLANCAR |   5 | 2024-04-08 | ongoing     |
-  | SKIM      |   1 | 2024-04-11 | might-break |
-  +-----------+-----+------------+-------------+
+  +-----------+-----+------------+---------+
+  | author    | len | start_date | status  |
+  +-----------+-----+------------+---------+
+  | PERLANCAR |  21 | 2024-04-16 | ongoing |
+  +-----------+-----+------------+---------+
 
 =head1 HOMEPAGE
 
