@@ -4,23 +4,21 @@ use strict;
 use warnings;
 
 our $AUTHORITY = 'cpan:PERLANCAR'; # AUTHORITY
-our $DATE = '2024-04-12'; # DATE
+our $DATE = '2024-05-06'; # DATE
 our $DIST = 'Acme-CPANAuthorsBundle-CPAN-Streaks'; # DIST
-our $VERSION = '20240412.0'; # VERSION
+our $VERSION = '20240506.0'; # VERSION
 
 use Acme::CPANAuthors::Register (
     'PERLANCAR' => '',
-    'SIDNEY' => '',
-    'BRIANDFOY' => '',
-    'MATHIAS' => '',
-    'PEVANS' => '',
-    'CORION' => '',
-    'INGY' => '',
+    'JOESUF' => '',
+    'JDEGUEST' => '',
+    'DDICK' => '',
+    'DRCLAW' => '',
+    'EGILES' => '',
     'LEONT' => '',
-    'NHORNE' => '',
-    'PAYJP' => '',
-    'SKIM' => '',
-    'TYRRMINAL' => '',
+    'MATHIAS' => '',
+    'OLOF' => '',
+    'TRIZEN' => '',
 );
 
 
@@ -39,29 +37,27 @@ Acme::CPANAuthors::CPAN::Streaks::DailyReleases::Current - Authors with ongoing
 
 =head1 VERSION
 
-This document describes version 20240412.0 of Acme::CPANAuthors::CPAN::Streaks::DailyReleases::Current (from Perl distribution Acme-CPANAuthorsBundle-CPAN-Streaks), released on 2024-04-12.
+This document describes version 20240506.0 of Acme::CPANAuthors::CPAN::Streaks::DailyReleases::Current (from Perl distribution Acme-CPANAuthorsBundle-CPAN-Streaks), released on 2024-05-06.
 
 =head1 SYNOPSIS
 
 =head1 DESCRIPTION
 
-Current standings (as of 2024-04-12, produced by L<cpan-streaks>):
+Current standings (as of 2024-05-06, produced by L<cpan-streaks>):
 
   +-----------+-----+------------+-------------+
   | author    | len | start_date | status      |
   +-----------+-----+------------+-------------+
-  | PERLANCAR |  50 | 2024-02-23 | ongoing     |
-  | SIDNEY    |  12 | 2024-03-31 | might-break |
-  | BRIANDFOY |   2 | 2024-04-10 | might-break |
-  | MATHIAS   |   2 | 2024-04-10 | might-break |
-  | PEVANS    |   2 | 2024-04-10 | might-break |
-  | CORION    |   1 | 2024-04-11 | might-break |
-  | INGY      |   1 | 2024-04-11 | might-break |
-  | LEONT     |   1 | 2024-04-11 | might-break |
-  | NHORNE    |   1 | 2024-04-11 | might-break |
-  | PAYJP     |   1 | 2024-04-11 | might-break |
-  | SKIM      |   1 | 2024-04-11 | might-break |
-  | TYRRMINAL |   1 | 2024-04-11 | might-break |
+  | PERLANCAR |  74 | 2024-02-23 | ongoing     |
+  | JOESUF    |   3 | 2024-05-03 | might-break |
+  | JDEGUEST  |   2 | 2024-05-04 | might-break |
+  | DDICK     |   1 | 2024-05-05 | might-break |
+  | DRCLAW    |   1 | 2024-05-05 | might-break |
+  | EGILES    |   1 | 2024-05-05 | might-break |
+  | LEONT     |   1 | 2024-05-05 | might-break |
+  | MATHIAS   |   1 | 2024-05-05 | might-break |
+  | OLOF      |   1 | 2024-05-05 | might-break |
+  | TRIZEN    |   1 | 2024-05-05 | might-break |
   +-----------+-----+------------+-------------+
 
 =head1 HOMEPAGE
